from django.contrib import admin

from ..models.tutorial import TutorialTranslation, Tutorial, TutorialSteps


class TranslationTutorialInline(admin.TabularInline):
    model = TutorialTranslation
    fields = ('language_code', 'tutorial_text', 'error_text')
    extra = 0


class TutorialStepsAdmin(admin.ModelAdmin):
    list_display = ('tutorial_step_id', 'tutorial', 'check_text', 'step', 'parent', 'branch')
    list_filter = ('tutorial__name',)
    fields = ('tutorial', 'step', "tutorial_text",  "check_text", "direction", "condition", 'get_parent_step', 'branch', "action")
    list_editable = ('parent',)
    readonly_fields = ('get_parent_step',)

    def copy_attributes(self, request, queryset):
        for objectAttr in reversed(queryset):
            objectAttr.pk = None
            objectAttr.step = objectAttr.step + 1
            objectAttr.save()

    copy_attributes.short_description = "Clone the selected TutorialStep"

    actions = [copy_attributes]

    inlines = [
        TranslationTutorialInline,
    ]


class TutorialAdmin(admin.ModelAdmin):
    list_display = ('name',)
    fields = ('name',)


admin.site.register(Tutorial, TutorialAdmin)
admin.site.register(TutorialSteps, TutorialStepsAdmin)
admin.autodiscover()
